#include "Pythia8/Pythia.h"
using namespace Pythia8;

int main() {
	// Declare Pythia object
	Pythia pythia;

	// Adjust Pythia configuration settings
	// - Enable g g -> t tbar
	pythia.readString("Top:gg2ttbar=on");

	// Initialize Pythia
	pythia.init();

	// Declare histograms for the charged particle multiplicity
	// Hint: Since the Hist class expects doubles, but we want to bin
	// integer values, we align the boundaries of the bins to half-integer
	// values so that the integers are not placed in the wrong bin due to
	// rounding errors which happended during the conversion to doubles.
	Hist histnch("n_charged", 100, -0.5, 499.5);

	// Event loop: We generate 1000 events
	for(int i = 0; i < 1000; i++)
	{
		// Generate one new event
		// This erases the current event record and fills it with the
		// particles generated in the new event
		pythia.next();

		// Count the number of charged, final state particles
		// We iterate over the event record and increase a counter each
		// time we encounter a particle which meets the above criteria.
		int nCharged = 0;
		for(int j=0; j < pythia.event.size(); j++)
		{
			if(pythia.event[j].isCharged()
			   && pythia.event[j].isFinal()) {
				nCharged++;
			}
		}

		// Bin the charged particle count
		histnch.fill((double)nCharged);
	}

	// Display the histograms
	cout << histnch;

	// End the program
	return(0);
}
