#include "Pythia8/Pythia.h"
using namespace Pythia8;

int main() {
	// Declare Pythia object
	Pythia pythia;

	// Adjust Pythia configuration settings
	// - Enable g g -> t tbar
	pythia.readString("Top:gg2ttbar=on");

	// Initialize Pythia
	pythia.init();

	// Declare histograms for the top quark properties
	// - transverse momentum (pT)
	Hist histpT(	"top pT",	// Name / short description (string)
			100,		// number of bins (integer)
			0.0,		// lower edge of the lowest bin
			400.0		// high edge of the highest bin
	);
	// - pseudorapidity (eta)
	Hist histeta("top eta", 100, -5.0, 5.0);
	// - angle to the beam axis (theta)
	Hist histtheta("top theta", 100, 0.0, 3.14156);

	// Event loop: We generate 1000 events
	for(int i = 0; i < 1000; i++)
	{
		// Generate one new event
		// This erases the current event record and fills it with the
		// particles generated in the new event
		pythia.next();

		// Search for the last occurrence of the top (PDG particle
		// id: 6). We loop over each entry in the event record and
		// check whether it is a top quark. If it is, we store its
		// index in iTop. After this loop iTop contains the index of
		// the last top contained in the event record.
		// Since the event record (at least the hard part) is
		// accumulated in "chonological" order, we know this is the
		// last instance of the top before it decayed.
		int iTop = -1;
		for(int j=0; j < pythia.event.size(); j++)
		{
			if(pythia.event[j].id() == 6) {
				iTop = j;
			}
		}

		// If we found a top, we bin its parameters in our historgrams.
		if(iTop>=0) {
			histpT.fill(pythia.event[iTop].pT());
			histeta.fill(pythia.event[iTop].eta());
			histtheta.fill(pythia.event[iTop].theta());
		}
	}

	// Display the histograms
	cout << histpT;
	cout << histeta;
	cout << histtheta;

	// End the program
	return(0);
}
